pyloger
=======

pyloger written in Python, for human beings.

This module is based on python's syslog,it provides an interface to the Unix syslog library routines. Refer to the Unix manual pages for a detailed description of the syslog facility.
